
#ifndef _C12_ev577_
#define _C12_ev577_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_REFERENCE F1225_11834(EIF_REFERENCE);
extern void EIF_Minit577(void);
extern EIF_REFERENCE F1233_11958(EIF_REFERENCE);
extern long O7511[];

#ifdef __cplusplus
}
#endif

#endif
